@@ -62,9 +62,12 @@ class StoryMixin:
         """
         story_id = self.media_id(story_pk)
         story_pk, user_id = story_id.split("_")
-        result = self.private_request(f"media/{story_pk}/info/")
-        story = extract_story_v1(result["items"][0])
-        self._stories_cache[story.pk] = story
+        # result = self.private_request(f"media/{story_pk}/info/")
+        # story = extract_story_v1(result["items"][0])
+        stories = self.user_stories_v1(user_id)
+        for story in stories:
+            self._stories_cache[story.pk] = story
+        story = self._stories_cache[story_pk]
         return deepcopy(story)
 
     def story_info(self, story_pk: str, use_cache: bool = True) -> Story:
